Index: boron_zen.info
===================================================================
RCS file: /cvs/drupal/contributions/themes/boron_zen/boron_zen.info,v
retrieving revision 1.1
diff -u -r1.1 boron_zen.info
--- boron_zen.info	5 Oct 2010 23:53:50 -0000	1.1
+++ boron_zen.info	21 Dec 2010 19:56:49 -0000
@@ -13,7 +13,7 @@
   ; base theme. Its unlikely you will ever need to change these, but they are
   ; required fields for a Zen sub-theme. The "engine" field is not used in a
   ; sub-theme since the engine is inherited from its base theme.
-core       = 6.x
+core       = 7.x
 base theme = zen
 
   ; This section adds CSS files to your theme. The media type is specified in
@@ -70,11 +70,14 @@
 regions[sidebar_second] = Second sidebar
 regions[navigation]     = Navigation bar
 regions[highlight]      = Highlighted content
+regions[highlighted] 	= Highlighted ; replaces $mission
 regions[content_top]    = Content top
 regions[content_bottom] = Content bottom
 regions[header]         = Header
 regions[footer]         = Footer
+regions[page_bottom] 	= Page bottom
 regions[page_closure]   = Page closure
+regions[page_top] 		= Page top
 
   ; Various page elements output by the theme can be toggled on and off. The
   ; "features" control which of these check boxes display on the
@@ -85,13 +88,13 @@
 features[] = logo
 features[] = name
 features[] = slogan
-features[] = mission
+;features[] = mission ; has been removed in D7
 features[] = node_user_picture
 features[] = comment_user_picture
 features[] = search
 features[] = favicon
-features[] = primary_links
-features[] = secondary_links
+features[] = main_menu
+features[] = secondary_menu
 
   ; Set the default settings to be used in theme-settings.php
 settings[zen_block_editing]        = 1
Index: css/blocks.css
===================================================================
RCS file: /cvs/drupal/contributions/themes/boron_zen/css/blocks.css,v
retrieving revision 1.1
diff -u -r1.1 blocks.css
--- css/blocks.css	5 Oct 2010 23:53:50 -0000	1.1
+++ css/blocks.css	21 Dec 2010 19:43:35 -0000
@@ -43,19 +43,19 @@
 #block-block-1 /* First administrator-defined block */ {
 }
 
-#block-blog-0 /* "Recent blog posts" block */ {
+#block-blog-recent /* "Recent blog posts" block */ {
 }
 
-#block-book-0 /* "Book navigation" block for the current book's table of contents */ {
+#block-book-navigation /* "Book navigation" block for the current book's table of contents */ {
 }
 
-#block-comment-0 /* "Recent comments" block */ {
+#block-comment-recent /* "Recent comments" block */ {
 }
 
-#block-forum-0 /* "Active forum topics" block */ {
+#block-forum-active /* "Active forum topics" block */ {
 }
 
-#block-forum-1 /* "New forum topics" block */ {
+#block-forum-new /* "New forum topics" block */ {
 }
 
 #block-menu-primary-links /* "Primary links" block */ {
@@ -64,29 +64,29 @@
 #block-menu-secondary-links /* "Secondary links" block */ {
 }
 
-#block-node-0 /* "Syndicate" block for primary RSS feed */ {
+#block-node-syndicate /* "Syndicate" block for primary RSS feed */ {
 }
 
-#block-poll-0 /* "Most recent poll" block */ {
+#block-poll-recent /* "Most recent poll" block */ {
 }
 
-#block-profile-0 /* "Author information" block for the profile of the page's author */ {
+#block-profile-author-information /* "Author information" block for the profile of the page's author */ {
 }
 
-#block-search-0 /* "Search form" block */ {
+#block-search-form /* "Search form" block */ {
 }
 
-#block-statistics-0 /* "Popular content" block */ {
+#block-statistics-popular /* "Popular content" block */ {
 }
 
-#block-user-0 /* "User login form" block */ {
+#block-user-login /* "User login form" block */ {
 }
 
-#block-user-1 /* "Navigation" block for Drupal navigation menu */ {
+#block-system-navigation /* "Navigation" block for Drupal navigation menu */ {
 }
 
-#block-user-2 /* "Who's new" block for a list of the newest users */ {
+#block-user-new /* "Who's new" block for a list of the newest users */ {
 }
 
-#block-user-3 /* "Who's online" block for a list of the online users */ {
+#block-user-online /* "Who's online" block for a list of the online users */ {
 }
Index: css/drupal6-reference.css
===================================================================
RCS file: /cvs/drupal/contributions/themes/boron_zen/css/drupal6-reference.css,v
retrieving revision 1.1
diff -u -r1.1 drupal6-reference.css
--- css/drupal6-reference.css	5 Oct 2010 23:53:50 -0000	1.1
+++ css/drupal6-reference.css	21 Dec 2010 19:49:35 -0000
@@ -932,7 +932,7 @@
 ** Markup free clearing
 ** Details: http://www.positioniseverything.net/easyclearing.html
 */
-.clear-block:after {
+.clearfix:after {
   content: ".";
   display: block;
   height: 0;
@@ -940,15 +940,15 @@
   visibility: hidden;
 }
 
-.clear-block {
+.clearfix {
   display: inline-block;
 }
 
 /* Hides from IE-mac \*/
-* html .clear-block {
+* html .clearfix {
   height: 1%;
 }
-.clear-block {
+.clearfix {
   display: block;
 }
 /* End hide from IE-mac */
Index: templates/book-navigation.tpl.php
===================================================================
RCS file: /cvs/drupal/contributions/themes/boron_zen/templates/book-navigation.tpl.php,v
retrieving revision 1.1
diff -u -r1.1 book-navigation.tpl.php
--- templates/book-navigation.tpl.php	5 Oct 2010 23:53:50 -0000	1.1
+++ templates/book-navigation.tpl.php	21 Dec 2010 19:49:35 -0000
@@ -35,7 +35,7 @@
     <?php print $tree; ?>
 
     <?php if ($has_links): ?>
-    <p class="page-links clear-block">
+    <p class="page-links clearfix">
       <?php if ($prev_url) : ?>
         <a href="<?php print $prev_url; ?>" class="page-previous" title="<?php print t('Go to previous page'); ?>"><?php print t('‹ ') . $prev_title; ?></a>
       <?php endif; ?>
Index: templates/forum-topic-navigation.tpl.php
===================================================================
RCS file: /cvs/drupal/contributions/themes/boron_zen/templates/forum-topic-navigation.tpl.php,v
retrieving revision 1.1
diff -u -r1.1 forum-topic-navigation.tpl.php
--- templates/forum-topic-navigation.tpl.php	5 Oct 2010 23:53:50 -0000	1.1
+++ templates/forum-topic-navigation.tpl.php	21 Dec 2010 19:49:35 -0000
@@ -24,7 +24,7 @@
  */
 ?>
 <?php if ($prev || $next): ?>
-  <footer class="forum-topic-navigation clear-block">
+  <footer class="forum-topic-navigation clearfix">
     <p class="page-links clearfix">
       <?php if ($prev): ?>
         <a href="<?php print $prev_url; ?>" class="topic-previous" title="<?php print t('Go to previous forum topic') ?>">‹ <?php print $prev_title ?></a>
Index: templates/page.tpl.php
===================================================================
RCS file: /cvs/drupal/contributions/themes/boron_zen/templates/page.tpl.php,v
retrieving revision 1.1
diff -u -r1.1 page.tpl.php
--- templates/page.tpl.php	5 Oct 2010 23:53:50 -0000	1.1
+++ templates/page.tpl.php	21 Dec 2010 19:55:16 -0000
@@ -66,9 +66,9 @@
  *
  * Navigation:
  * - $search_box: HTML to display the search box, empty if search has been disabled.
  * - $primary_links (array): An array containing the Primary menu links for the
  *   site, if they have been configured.
  * - $secondary_links (array): An array containing the Secondary menu links for
  *   the site, if they have been configured.
  * - $breadcrumb: The breadcrumb trail for the current page.
  *
@@ -110,8 +110,8 @@
  */
 ?>
 <!DOCTYPE html>
-<html lang="<?php print $language->language; ?>" dir="<?php print $language->dir; ?>">
-<head>
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="<?php print $language->language ?>" dir="<?php print $language->dir ?>" <?php print $rdf_namespaces ?>>
+<head profile="<?php print $grddl_profile ?>">
   <title><?php print $head_title; ?></title>
   <?php print $head; ?>
   <?php print $styles; ?>
@@ -119,7 +119,7 @@
 </head>
 <body class="<?php print $classes; ?>">
 
-  <?php if ($primary_links): ?>
+  <?php if ($main_menu): ?>
     <div id="skip-link"><em><a href="#main-menu"><?php print t('Jump to Navigation'); ?></a></em> &darr;</div>
   <?php endif; ?>
 
@@ -161,12 +161,12 @@
     
     <hr />
 
-    <div id="main-wrapper"><div id="main" class="clearfix<?php if ($primary_links || $navigation) { print ' with-navigation'; } ?>">
+    <div id="main-wrapper"><div id="main" class="clearfix<?php if ($main_menu || $navigation) { print ' with-navigation'; } ?>">
 
       <div id="content" class="column"><div class="section">
 
         <?php if ($mission): ?>
-          <div id="mission"><?php print $mission; ?></div>
+          <div id="mission"><?php print render($page['highlighted']); ?></div>
         <?php endif; ?>
 
         <?php print $highlight; ?>
@@ -201,10 +201,10 @@
       
       <hr />
 
-      <?php if ($primary_links || $navigation): ?>
+      <?php if ($main_menu || $navigation): ?>
         <nav id="navigation"><div class="section clearfix">
 
-          <?php print theme(array('links__system_main_menu', 'links'), $primary_links,
+          <?php print theme(array('links__system_main_menu', 'links'), $main_menu,
             array(
               'id' => 'main-menu',
               'class' => 'links clearfix',
@@ -229,10 +229,10 @@
     
     <hr />
 
-    <?php if ($footer || $footer_message || $secondary_links): ?>
+    <?php if ($footer || $footer_message || $secondary_menu): ?>
       <footer id="footer"><div class="section">
 
-        <?php print theme(array('links__system_secondary_menu', 'links'), $secondary_links,
+        <?php print theme(array('links__system_secondary_menu', 'links'), $secondary_menu,
           array(
             'id' => 'secondary-menu',
             'class' => 'links clearfix',
@@ -257,7 +257,7 @@
 
   <?php print $page_closure; ?>
 
-  <?php print $closure; ?>
+  <?php print $page_bottom; ?>
 
 </body>
 </html>
@@ -66,9 +66,9 @@
  * Navigation:
  * - $search_box: HTML to display the search box, empty if search has been disabled.
- * - $primary_links (array): An array containing the Primary menu links for the
+ * - $main_menu (array): An array containing the Primary menu links for the
  *   site, if they have been configured.
@@ -66,9 +66,9 @@
  *   site, if they have been configured.
- * - $secondary_links (array): An array containing the Secondary menu links for
+ * - $secondary_menu (array): An array containing the Secondary menu links for
  *   the site, if they have been configured.
  * - $breadcrumb: The breadcrumb trail for the current page.

